@@ -9,26 +9,25 @@
  */
 namespace PHPUnit\Framework\Constraint;
 
-use function get_class;
+use function explode;
+use function gettype;
 use function is_array;
 use function is_object;
 use function is_string;
 use function sprintf;
 use PHPUnit\Framework\ExpectationFailedException;
+use PHPUnit\Util\Exporter;
 use SebastianBergmann\Comparator\ComparisonFailure;
-use SebastianBergmann\RecursionContext\InvalidArgumentException;
+use UnitEnum;
 
 /**
  * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
  */
 final class IsIdentical extends Constraint
 {
-    /**
-     * @var mixed
-     */
-    private $value;
+    private readonly mixed $value;
 
-    public function __construct($value)
+    public function __construct(mixed $value)
     {
         $this->value = $value;
     }
@@ -44,9 +43,8 @@ final class IsIdentical extends Constraint
      * failure.
      *
      * @throws ExpectationFailedException
-     * @throws InvalidArgumentException
      */
-    public function evaluate($other, string $description = '', bool $returnResult = false): ?bool
+    public function evaluate(mixed $other, string $description = '', bool $returnResult = false): ?bool
     {
         $success = $this->value === $other;
 
@@ -67,13 +65,13 @@ final class IsIdentical extends Constraint
                 );
             }
 
-            // if both values are array, make sure a diff is generated
-            if (is_array($this->value) && is_array($other)) {
+            // if both values are array or enums, make sure a diff is generated
+            if ((is_array($this->value) && is_array($other)) || ($this->value instanceof UnitEnum && $other instanceof UnitEnum)) {
                 $f = new ComparisonFailure(
                     $this->value,
                     $other,
-                    $this->exporter()->export($this->value),
-                    $this->exporter()->export($other),
+                    Exporter::export($this->value),
+                    Exporter::export($other),
                 );
             }
 
@@ -85,17 +83,15 @@ final class IsIdentical extends Constraint
 
     /**
      * Returns a string representation of the constraint.
-     *
-     * @throws InvalidArgumentException
      */
     public function toString(): string
     {
         if (is_object($this->value)) {
             return 'is identical to an object of class "' .
-                get_class($this->value) . '"';
+                $this->value::class . '"';
         }
 
-        return 'is identical to ' . $this->exporter()->export($this->value);
+        return 'is identical to ' . Exporter::export($this->value);
     }
 
     /**
@@ -103,17 +99,17 @@ final class IsIdentical extends Constraint
      *
      * The beginning of failure messages is "Failed asserting that" in most
      * cases. This method should return the second part of that sentence.
-     *
-     * @param mixed $other evaluated value or object
-     *
-     * @throws InvalidArgumentException
      */
-    protected function failureDescription($other): string
+    protected function failureDescription(mixed $other): string
     {
         if (is_object($this->value) && is_object($other)) {
             return 'two variables reference the same object';
         }
 
+        if (explode(' ', gettype($this->value), 2)[0] === 'resource' && explode(' ', gettype($other), 2)[0] === 'resource') {
+            return 'two variables reference the same resource';
+        }
+
         if (is_string($this->value) && is_string($other)) {
             return 'two strings are identical';
         }
