@@ -14,6 +14,7 @@ use const PHP_MINOR_VERSION;
 use function array_keys;
 use function array_reverse;
 use function array_shift;
+use function assert;
 use function defined;
 use function get_defined_constants;
 use function get_included_files;
@@ -25,19 +26,21 @@ use function is_scalar;
 use function preg_match;
 use function serialize;
 use function sprintf;
-use function strpos;
+use function str_ends_with;
+use function str_starts_with;
 use function strtr;
-use function substr;
 use function var_export;
 use Closure;
 
 /**
+ * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
+ *
  * @internal This class is not covered by the backward compatibility promise for PHPUnit
  */
-final class GlobalState
+final readonly class GlobalState
 {
     /**
-     * @var string[]
+     * @var list<string>
      */
     private const SUPER_GLOBAL_ARRAYS = [
         '_ENV',
@@ -50,7 +53,7 @@ final class GlobalState
     ];
 
     /**
-     * @psalm-var array<string, array<string, true>>
+     * @var array<string, array<string, true>>
      */
     private const DEPRECATED_INI_SETTINGS = [
         '7.3' => [
@@ -131,7 +134,7 @@ final class GlobalState
     }
 
     /**
-     * @param string[] $files
+     * @param list<string> $files
      *
      * @throws Exception
      */
@@ -142,15 +145,19 @@ final class GlobalState
         $result      = '';
 
         if (defined('__PHPUNIT_PHAR__')) {
+            // @codeCoverageIgnoreStart
             $prefix = 'phar://' . __PHPUNIT_PHAR__ . '/';
+            // @codeCoverageIgnoreEnd
         }
 
         // Do not process bootstrap script
         array_shift($files);
 
         // If bootstrap script was a Composer bin proxy, skip the second entry as well
-        if (substr(strtr($files[0], '\\', '/'), -24) === '/phpunit/phpunit/phpunit') {
+        if (str_ends_with(strtr($files[0], '\\', '/'), '/phpunit/phpunit/phpunit')) {
+            // @codeCoverageIgnoreStart
             array_shift($files);
+            // @codeCoverageIgnoreEnd
         }
 
         foreach (array_reverse($files) as $file) {
@@ -159,7 +166,7 @@ final class GlobalState
                 continue;
             }
 
-            if ($prefix !== false && strpos($file, $prefix) === 0) {
+            if ($prefix !== false && str_starts_with($file, $prefix)) {
                 continue;
             }
 
@@ -180,7 +187,11 @@ final class GlobalState
     {
         $result = '';
 
-        foreach (ini_get_all(null, false) as $key => $value) {
+        $iniSettings = ini_get_all(null, false);
+
+        assert($iniSettings !== false);
+
+        foreach ($iniSettings as $key => $value) {
             if (self::isIniSettingDeprecated($key)) {
                 continue;
             }
@@ -188,7 +199,7 @@ final class GlobalState
             $result .= sprintf(
                 '@ini_set(%s, %s);' . "\n",
                 self::exportVariable($key),
-                self::exportVariable((string) $value)
+                self::exportVariable((string) $value),
             );
         }
 
@@ -206,7 +217,7 @@ final class GlobalState
                     'if (!defined(\'%s\')) define(\'%s\', %s);' . "\n",
                     $name,
                     $name,
-                    self::exportVariable($value)
+                    self::exportVariable($value),
                 );
             }
         }
@@ -229,7 +240,7 @@ final class GlobalState
                         '$GLOBALS[\'%s\'][\'%s\'] = %s;' . "\n",
                         $superGlobalArray,
                         $key,
-                        self::exportVariable($GLOBALS[$superGlobalArray][$key])
+                        self::exportVariable($GLOBALS[$superGlobalArray][$key]),
                     );
                 }
             }
@@ -243,7 +254,7 @@ final class GlobalState
                 $result .= sprintf(
                     '$GLOBALS[\'%s\'] = %s;' . "\n",
                     $key,
-                    self::exportVariable($GLOBALS[$key])
+                    self::exportVariable($GLOBALS[$key]),
                 );
             }
         }
@@ -251,7 +262,7 @@ final class GlobalState
         return $result;
     }
 
-    private static function exportVariable($variable): string
+    private static function exportVariable(mixed $variable): string
     {
         if (is_scalar($variable) || $variable === null ||
             (is_array($variable) && self::arrayOnlyContainsScalars($variable))) {
@@ -261,6 +272,9 @@ final class GlobalState
         return 'unserialize(' . var_export(serialize($variable), true) . ')';
     }
 
+    /**
+     * @param array<mixed> $array
+     */
     private static function arrayOnlyContainsScalars(array $array): bool
     {
         $result = true;
