@@ -12,19 +12,15 @@ namespace PHPUnit\TestFixture;
 use PHPUnit\Framework\TestCase;
 
 /**
- * @author Companion Cube
- *
  * @ticket t123456
  */
-class NumericGroupAnnotationTest extends TestCase
+final class NumericGroupAnnotationTest extends TestCase
 {
     /**
      * @testdox Empty test for @ticket numeric annotation values
      *
      * @ticket  3502
      *
-     * @author C. Lippy
-     *
      * @see https://github.com/sebastianbergmann/phpunit/issues/3502
      */
     public function testTicketAnnotationSupportsNumericValue(): void
