@@ -10,6 +10,7 @@
 namespace PHPUnit\Framework\MockObject;
 
 use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\IgnorePhpunitDeprecations;
 use PHPUnit\Framework\Attributes\Medium;
 use PHPUnit\Framework\Attributes\RequiresPhpExtension;
 use PHPUnit\Framework\Attributes\TestDox;
@@ -21,16 +22,17 @@ use PHPUnit\Framework\TestCase;
 #[Medium]
 #[RequiresPhpExtension('soap')]
 #[TestDox('getMockFromWsdl()')]
+#[IgnorePhpunitDeprecations]
 final class GetMockFromWsdlTest extends TestCase
 {
     #[TestDox('Creates mock object from WSDL file')]
-    public function test_CreatesMockObjectFromWsdlFileWithNonNamespacedClassName(): void
+    public function testCreatesMockObjectFromWsdlFileWithNonNamespacedClassName(): void
     {
-        $mock = $this->getMockFromWsdl(TEST_FILES_PATH . 'GoogleSearch.wsdl');
+        $double = $this->getMockFromWsdl(TEST_FILES_PATH . 'GoogleSearch.wsdl');
 
         $this->assertStringStartsWith(
-            'Mock_GoogleSearch_',
-            $mock::class,
+            'MockObject_GoogleSearch_',
+            $double::class,
         );
     }
 }
