@@ -23,6 +23,8 @@ use PHPUnit\TestFixture\MockObject\AnInterfaceForIssue5593;
 use PHPUnit\TestFixture\MockObject\AnotherInterface;
 use PHPUnit\TestFixture\MockObject\AnotherInterfaceForIssue5593;
 use PHPUnit\TestFixture\MockObject\ExtendableClass;
+use PHPUnit\TestFixture\MockObject\InterfaceWithMethodThatReturnsSelf;
+use PHPUnit\TestFixture\MockObject\InterfaceWithMethodThatReturnsStatic;
 use PHPUnit\TestFixture\MockObject\YetAnotherInterface;
 use stdClass;
 
@@ -168,11 +170,24 @@ final class ReturnValueGeneratorTest extends TestCase
         $this->assertInstanceOf(AnotherInterface::class, $value);
     }
 
+    public function test_Generates_new_instance_of_test_stub_for_self(): void
+    {
+        $stub = $this->createStub(InterfaceWithMethodThatReturnsSelf::class);
+
+        $returnValue = $stub->doSomething();
+
+        $this->assertNotInstanceOf($stub::class, $returnValue);
+        $this->assertNotSame($stub, $returnValue);
+    }
+
     public function test_Generates_new_instance_of_test_stub_for_static(): void
     {
-        $stubClassName = ($this->createStub(AnInterface::class))::class;
+        $stub = $this->createStub(InterfaceWithMethodThatReturnsStatic::class);
 
-        $this->assertInstanceOf($stubClassName, $this->generate('static', $stubClassName));
+        $returnValue = $stub->doSomething();
+
+        $this->assertInstanceOf($stub::class, $returnValue);
+        $this->assertNotSame($stub, $returnValue);
     }
 
     #[Ticket('https://github.com/sebastianbergmann/phpunit/issues/5593')]
@@ -241,12 +256,16 @@ final class ReturnValueGeneratorTest extends TestCase
         $this->assertInstanceOf(Stub::class, $this->generate('ThisDoesNotExist'));
     }
 
-    private function generate(string $typeDeclaration, string $stubClassName = 'StubClassName'): mixed
+    private function generate(string $typeDeclaration, ?StubInternal $testStub = null): mixed
     {
+        if ($testStub === null) {
+            $testStub = $this->createStub(AnInterface::class);
+        }
+
         return (new ReturnValueGenerator)->generate(
             'OriginalClassName',
             'methodName',
-            $stubClassName,
+            $testStub,
             $typeDeclaration,
         );
     }
