@@ -10,11 +10,14 @@
 namespace PHPUnit\Metadata\Parser;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Metadata\MetadataCollection;
 
 #[CoversClass(ParserChain::class)]
 #[Small]
+#[Group('metadata')]
+#[Group('metadata/annotations')]
 final class ChainedAnnotationParserTest extends AnnotationParserTestCase
 {
     protected function parser(): Parser
