@@ -9,6 +9,7 @@
  */
 namespace PHPUnit\TextUI\Configuration;
 
+use const DIRECTORY_SEPARATOR;
 use function realpath;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
@@ -26,8 +27,10 @@ final class SourceFilterTest extends TestCase
         return [
             'file included using file' => [
                 true,
-                $fixtureDirectory . '/a/PrefixSuffix.php',
+                $fixtureDirectory . DIRECTORY_SEPARATOR . 'a' . DIRECTORY_SEPARATOR . 'PrefixSuffix.php',
                 new Source(
+                    null,
+                    false,
                     FilterDirectoryCollection::fromArray([]),
                     FileCollection::fromArray(
                         [
@@ -46,12 +49,21 @@ final class SourceFilterTest extends TestCase
                     false,
                     false,
                     false,
+                    [
+                        'functions' => [],
+                        'methods'   => [],
+                    ],
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using file, but excluded using directory' => [
                 false,
-                $fixtureDirectory . '/a/PrefixSuffix.php',
+                $fixtureDirectory . DIRECTORY_SEPARATOR . 'a' . DIRECTORY_SEPARATOR . 'PrefixSuffix.php',
                 new Source(
+                    null,
+                    false,
                     FilterDirectoryCollection::fromArray([]),
                     FileCollection::fromArray(
                         [
@@ -78,12 +90,21 @@ final class SourceFilterTest extends TestCase
                     false,
                     false,
                     false,
+                    [
+                        'functions' => [],
+                        'methods'   => [],
+                    ],
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using file, but excluded using file' => [
                 false,
-                $fixtureDirectory . '/a/PrefixSuffix.php',
+                $fixtureDirectory . DIRECTORY_SEPARATOR . 'a' . DIRECTORY_SEPARATOR . 'PrefixSuffix.php',
                 new Source(
+                    null,
+                    false,
                     FilterDirectoryCollection::fromArray([]),
                     FileCollection::fromArray(
                         [
@@ -106,12 +127,21 @@ final class SourceFilterTest extends TestCase
                     false,
                     false,
                     false,
+                    [
+                        'functions' => [],
+                        'methods'   => [],
+                    ],
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using directory' => [
                 true,
-                $fixtureDirectory . '/a/PrefixSuffix.php',
+                $fixtureDirectory . DIRECTORY_SEPARATOR . 'a' . DIRECTORY_SEPARATOR . 'PrefixSuffix.php',
                 new Source(
+                    null,
+                    false,
                     FilterDirectoryCollection::fromArray(
                         [
                             new FilterDirectory(
@@ -134,12 +164,21 @@ final class SourceFilterTest extends TestCase
                     false,
                     false,
                     false,
+                    [
+                        'functions' => [],
+                        'methods'   => [],
+                    ],
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using directory, but excluded using file' => [
                 false,
-                $fixtureDirectory . '/a/PrefixSuffix.php',
+                $fixtureDirectory . DIRECTORY_SEPARATOR . 'a' . DIRECTORY_SEPARATOR . 'PrefixSuffix.php',
                 new Source(
+                    null,
+                    false,
                     FilterDirectoryCollection::fromArray(
                         [
                             new FilterDirectory(
@@ -166,12 +205,21 @@ final class SourceFilterTest extends TestCase
                     false,
                     false,
                     false,
+                    [
+                        'functions' => [],
+                        'methods'   => [],
+                    ],
+                    false,
+                    false,
+                    false,
                 ),
             ],
             'file included using directory, but excluded using directory' => [
                 false,
-                $fixtureDirectory . '/a/PrefixSuffix.php',
+                $fixtureDirectory . DIRECTORY_SEPARATOR . 'a' . DIRECTORY_SEPARATOR . 'PrefixSuffix.php',
                 new Source(
+                    null,
+                    false,
                     FilterDirectoryCollection::fromArray(
                         [
                             new FilterDirectory(
@@ -202,6 +250,13 @@ final class SourceFilterTest extends TestCase
                     false,
                     false,
                     false,
+                    [
+                        'functions' => [],
+                        'methods'   => [],
+                    ],
+                    false,
+                    false,
+                    false,
                 ),
             ],
         ];
